@@ -141,9 +141,16 @@ matrix2dfm <- function(x, docvars = NULL, meta = NULL) {
         docvars <- make_docvars(nrow(x), docname, FALSE)
     if (is.null(meta))
         meta <- make_meta("dfm")
-
+    
+    if (nrow(x) == 0 && ncol(x) == 0) {
+        # avoid coercion to ldiMatrix
+        x <- as(matrix(nrow = 0, ncol = 0), "dgeMatrix")
+    } else {
+        x <- Matrix(x, sparse = TRUE)
+    }
+    
     build_dfm(
-        as(Matrix(x, sparse = TRUE), "dgCMatrix"),
+        as(x, "dgCMatrix"),
         featname,
         docvars = docvars,
         meta = meta
