@@ -5,8 +5,6 @@
 #' Get or set the object metadata in a [corpus], [tokens], [dfm], or
 #' [dictionary] object. With the exception of dictionaries, this will be
 #' corpus-level metadata.
-#'
-#' `metacorpus` and `metacorpus<-` are synonyms but are deprecated.
 #' @param x an object for which the metadata will be read or set
 #' @param field metadata field name(s); if `NULL` (default), return all
 #'   metadata names
@@ -19,7 +17,6 @@
 #'   user-level metadata may be assigned.
 #' @export
 #' @keywords corpus
-#' @aliases metacorpus
 #' @examples
 #' meta(data_corpus_inaugural)
 #' meta(data_corpus_inaugural, "source")
@@ -30,7 +27,7 @@ meta <- function(x, field = NULL, type = c("user", "object", "system", "all"))
 
 #' @export
 meta.default <- function(x, field = NULL, type = c("user", "object", "system", "all")) {
-    stop(friendly_class_undefined_message(class(x), "meta"))
+    check_class(class(x), "meta")
 }
 
 #' @export
@@ -71,12 +68,10 @@ select_meta <- function(x, field = NULL, type = c("user", "object", "system", "a
 
 # meta<-   -----------
 
-#' Replacement function for corpus-level data
+#' @rdname meta
 #' @param value new value of the metadata field
 #' @export
-#' @rdname meta
-#' @aliases "metacorpus<-"
-"meta<-" <- "metacorpus<-" <- function(x, field = NULL, value) {
+"meta<-" <- function(x, field = NULL, value) {
     if (is.null(field) && !is.list(value)) stop("value must be a named list")
         if (is.list(value) && length(names(value)) != length(value))
         stop("every element of the meta list must be named")
@@ -124,17 +119,6 @@ select_meta <- function(x, field = NULL, type = c("user", "object", "system", "a
     return(x)
 }
 
-
-# legacy functions ----------
-
-#' @rdname meta
-#' @export
-metacorpus <- meta
-
-#' @rdname meta
-#' @export
-`metacorpus<-` <- `meta<-`
-
 # internal: meta_system ----------------
 
 #' Internal function to get, set or initialize system metadata
@@ -182,7 +166,6 @@ meta_system <- function(x, field = NULL)
     return(x)
 }
 
-
 #' @rdname meta_system
 `meta_system<-.dfm` <- function(x, field = NULL, value) {
     if (is.null(field)) {
@@ -212,7 +195,7 @@ meta_system_defaults <- function() {
 
 # make_meta ------------
 
-#' Internal functions to create a list for the meta attribute
+#' Internal functions to create a list of the meta fields
 #' @param class object class either `dfm`, `tokens` or `corpus`
 #' @param inherit list from the meta attribute
 #' @param ... values assigned to the object meta fields
@@ -237,6 +220,8 @@ make_meta <- function(class, inherit = NULL, ...) {
         result$object <- make_meta_tokens(inherit$object, ...)
     } else if (class == "dfm") {
         result$object <- make_meta_dfm(inherit$object, ...)
+    } else if (class == "fcm") {
+        result$object <- make_meta_fcm(inherit$object, ...)
     } else if (class == "dictionary2") {
         result$object <- make_meta_dictionary2(inherit, ...)
     }
@@ -248,6 +233,7 @@ make_meta <- function(class, inherit = NULL, ...) {
 }
 
 # newer version of meta_system_defaults
+#' @rdname make_meta
 make_meta_system <- function(inherit = NULL) {
     if (is.null(inherit))
         inherit <- list()
@@ -308,6 +294,25 @@ make_meta_dfm <- function(inherit = NULL, ...) {
     update_meta(default, inherit, ...)
 }
 
+#' @rdname make_meta
+make_meta_fcm <- function(inherit = NULL, ...) {
+    if (is.null(inherit))
+        inherit <- list()
+    default <- list(
+        "unit" = "documents",
+        "concatenator" = "_",
+        "what" = "word",
+        "context" = "document", 
+        "window" = 5L,
+        "count" = "frequency",
+        "weights" = 1,
+        "ordered" = FALSE,
+        "margin" = numeric(), 
+        "tri" = FALSE
+    )
+    update_meta(default, inherit, ..., warn = FALSE)
+}
+
 #' @rdname make_meta
 make_meta_dictionary2 <- function(inherit = NULL, ...) {
     if (is.null(inherit))
@@ -319,10 +324,11 @@ make_meta_dictionary2 <- function(inherit = NULL, ...) {
 
 #' @rdname make_meta
 #' @param default default values for the meta attribute
-update_meta <- function(default, inherit, ...) {
+update_meta <- function(default, inherit, ..., warn = TRUE) {
     update <- list(...)
     for (m in setdiff(union(names(inherit), names(update)), names(default))) {
-        warning(m, " is ignored.")
+        if (warn)
+            warning(m, " is ignored.")
     }
     for (m in names(default)) {
         if (length(update) && m %in% names(update)) {
