@@ -1,21 +1,27 @@
 # documentation function -------
 
-#' Object compilers
-#' 
+#' Object builders
+#'
 #' Functions to build or re-build core objects, or to upgrade earlier versions
 #' of these objects to the current format.
 #' @name object-builders
-#' @param x an input [corpus], [dfm], [tokens], or [dictionary] object
-#' @param ... further objects passed to object metadata
+#' @param x an input [corpus], [tokens], [dfm], [fcm] or [dictionary] object.
+#' @param meta a list for the meta fields (system, object, user). Used to
+#'   inherit values in the meta fields from input object. Object meta fields
+#'   that are not defined in [quanteda::make_meta()] are ignored with warnings.
+#' @param ... values saved in the object meta fields. They overwrite values
+#'   passed via `meta`. If not specified, default values in
+#'   [quanteda::make_meta()] will be used.
 #' @keywords internal
 NULL
 
 # dfm --------------
 
 #' @rdname object-builders
-#' @param features character for feature of resulting `dfm`
-#' @param docvars data.frame for document level variables
-#' @param meta list for meta fields
+#' @param features character for feature of resulting `dfm`.
+#' @param docvars data.frame for document level variables created by
+#'   [make_docvars()]. Names of documents are extracted from the
+#'   `docname_` column.
 #' @keywords internal
 build_dfm <- function(x, features,
                       docvars = data.frame(), meta = list(), 
@@ -46,6 +52,11 @@ rebuild_dfm <- function(x, attrs) {
 upgrade_dfm <- function(x) {
     if (!is_pre2(x)) return(x)
     attrs <- attributes(x)
+    if ("meta" %in% names(attrs)) {
+        x@docvars <- upgrade_docvars(attrs$docvars, rownames(x))
+        return(x)
+    }
+    
     build_dfm(
         x, colnames(x),
         docvars = upgrade_docvars(attrs$docvars, rownames(x)),
@@ -63,13 +74,21 @@ upgrade_dfm <- function(x) {
                     ),
                     user = list())
     )
+
 }
 
 # tokens -------
 
 #' @rdname object-builders
-#' @param types character for types of resulting `tokens`` object
-#' @param padding logical indicating if the `tokens` object contains paddings
+#' @param types character for types of resulting the `tokens` object.
+#' @param padding logical indicating if the `tokens` object contains paddings.
+#' @examples 
+#' quanteda:::build_tokens(
+#'     list(c(1, 2, 3), c(4, 5, 6)),
+#'     docvars = quanteda:::make_docvars(n = 2L),
+#'     types = c("a", "b", "c", "d", "e", "f"),
+#'     padding = FALSE
+#' )
 build_tokens <- function(x, types, padding = FALSE,
                          docvars = data.frame(), meta = list(), 
                          class = "tokens", ...) {
@@ -91,7 +110,7 @@ rebuild_tokens <- function(x, attrs) {
     attr(x, "meta") <- attrs[["meta"]]
     attr(x, "class") <- union(attrs[["class"]], "tokens")
 
-    # drop extra attribues for tokens_segment
+    # drop extra attributes from tokens_segment
     try({attr(x, "docnum") <- NULL}, silent = TRUE)
     try({attr(x, "pattern") <- NULL}, silent = TRUE)
 
@@ -102,6 +121,11 @@ rebuild_tokens <- function(x, attrs) {
 upgrade_tokens <- function(x) {
     if (!is_pre2(x)) return(x)
     attrs <- attributes(x)
+    if ("meta" %in% names(attrs)) {
+        attr(x, "docvars") <- upgrade_docvars(attrs$docvars, names(x))
+        return(x)
+    }
+    
     x <- unclass(x)
     build_tokens(
         x, attrs[["types"]],
@@ -124,7 +148,13 @@ upgrade_tokens <- function(x) {
 # corpus --------
 
 #' @rdname object-builders
-#' @param class class to be attached to the built object
+#' @param class class labels to be attached to the object.
+#' @examples 
+#' quanteda:::build_corpus(
+#'     c("a b c", "d e f"),
+#'     docvars = quanteda:::make_docvars(n = 2L),
+#'     unit = "sentence"
+#' )
 build_corpus <- function(x,
                          docvars = data.frame(),
                          meta = list(),
@@ -152,6 +182,11 @@ rebuild_corpus <- function(x, attrs) {
 upgrade_corpus <- function(x) {
     if (!is_pre2(x)) return(x)
     attrs <- attributes(x)
+    if ("meta" %in% names(attrs)) {
+        attr(x, "docvars") <- upgrade_docvars(attrs$docvars, names(x))
+        return(x)
+    }
+    
     x <- unclass(x)
     if ("documents" %in% names(x)) {
         if ("settings" %in% names(x)) {
@@ -175,7 +210,6 @@ upgrade_corpus <- function(x) {
                         object = list(unit = attrs[["unit"]]),
                         user = attrs[["meta"]][["user"]])
         )
-
     }
 }
 
@@ -204,3 +238,57 @@ upgrade_dictionary2 <- function(x) {
                       separator = attrs[["concatenator"]],
                       valuetype = "glob")
 }
+
+# fcm ------
+
+#' @rdname object-builders
+#' @param features1 character for row feature of resulting `fcm`.
+#' @param features2 character for column feature of resulting `fcm` iff.
+#'   different from `feature1`
+#' @param meta list for meta fields
+#' @keywords internal
+build_fcm <- function(x, features1, features2 = NULL,
+                      meta = list(), 
+                      class = "fcm", ...) {
+    result <- new(class,
+                  as(x, "dgCMatrix"),
+                  meta = make_meta("fcm", inherit = meta, ...)
+    )
+    # set names directly to avoid NULL
+    if (is.null(features2))
+        features2 <- features1
+    result@Dimnames <- list(
+        features = as.character(features1),
+        features = as.character(features2)
+    )
+    return(result)
+}
+
+#' @rdname object-builders
+#' @param attrs a list of attributes to be reassigned
+rebuild_fcm <- function(x, attrs) {
+    x@meta <- attrs[["meta"]]
+    return(x)
+}
+
+
+#' @rdname object-builders
+upgrade_fcm <- function(x) {
+    if (!is_pre2(x)) return(x)
+    attrs <- attributes(x)
+    build_fcm(
+        x, rownames(x), colnames(x),
+        meta = list(system = list(),
+                    object = list(
+                        concatenator = "_",
+                        context = attrs[["context"]], 
+                        window = attrs[["window"]], 
+                        count = attrs[["count"]], 
+                        weights = attrs[["weights"]], 
+                        ordered = attrs[["ordered"]], 
+                        margin = attrs[["margin"]], 
+                        tri = attrs[["tri"]]
+                    ),
+                    user = list())
+    )
+}
