@@ -354,6 +354,11 @@ test_that("kwic works as expected with and without phrases", {
         c("e g h", "e g h")
     )
 
+    expect_equal(
+        as.data.frame(kwic(txt, as.phrase(coll_bi)))$keyword,
+        c("a b", "e g", "g h",
+          "a b", "e g", "g h")
+    )
     expect_equal(
         as.data.frame(kwic(txt, phrase(coll_bi)))$keyword,
         c("a b", "e g", "g h",
@@ -401,11 +406,11 @@ test_that("kwic works as expected with and without phrases", {
     expect_equal(nrow(kwic(toks_uni, coll_tri)), 2)
 
     expect_equal(
-        as.data.frame(kwic(toks_uni, phrase(coll_bi)))$keyword,
+        as.data.frame(kwic(toks_uni, as.phrase(coll_bi)))$keyword,
         c("a b", "e g", "g h", "a b", "e g", "g h")
     )
     expect_equal(
-        nrow(kwic(toks_bi, phrase(coll_bi))),
+        nrow(kwic(toks_bi, as.phrase(coll_bi))),
         0
     )
 
