@@ -1,5 +1,3 @@
-context("test tokens_replace")
-
 txt <- c(doc1 = "aa bb BB cc DD ee",
          doc2 = "aa bb cc DD ee")
 toks_test <- tokens(txt)
@@ -139,10 +137,10 @@ test_that("tokens_replace can reconstruct original by re-replacement", {
 test_that("tokens_replace raises error when input values are invalid", {
     # error when lenfths of from and to are different
     expect_error(tokens_replace(toks_test, c('aa', 'bb'), c('a')),
-                 "Lengths of 'pattern' and 'replacement' must be the same")
+                 "The length of pattern and replacement must be the same")
     
     expect_error(tokens_replace(toks_test, c(1, 2), c(10, 20), valuetype = "fixed"),
-                 "'pattern' and 'replacement' must be characters")
+                 "The type of pattern must be character")
     
     # does nothing when input vector is zero length
     expect_equal(tokens_replace(toks_test, character(), character()),
