@@ -1,5 +1,3 @@
-context("test wordstem")
-
 test_that("character wordstem test to test testing.", {
     expect_equal(char_wordstem("testing", "porter"), "test")
     expect_equal(char_wordstem("testing", "english"), "test")
@@ -7,12 +5,14 @@ test_that("character wordstem test to test testing.", {
 
 test_that("can wordstem dfms with zero features and zero docs", {
     # zero feature documents
-    dfmt1 <- dfm(c("one", "0"), stem = TRUE, remove_numbers = TRUE)
-    dfmt2 <- dfm(c("one", "!!"), stem = TRUE, remove_punct = TRUE)
+    dfmt1 <- dfm(tokens(c("one", "0"), remove_numbers = TRUE)) %>%
+        dfm_wordstem()
+    dfmt2 <- dfm(tokens(c("one", "!!"), remove_punct = TRUE)) %>%
+        dfm_wordstem()
     expect_equal(ndoc(dfmt1), ndoc(dfmt2), 2)
 
     # features with zero docfreq
-    dfmt3 <- dfm(c("stemming porter three", "stemming four five"))
+    dfmt3 <- dfm(tokens(c("stemming porter three", "stemming four five")))
     dfmt3[2, 4] <- 0
     dfmt3 <- as.dfm(dfmt3)
     dfm_wordstem(dfmt3, language = "english")
